pub struct ChannelExtInfo {
Show 14 fields pub from_nick: Option<Vec<u8>>, pub guild_name: Option<Vec<u8>>, pub channel_name: Option<Vec<u8>>, pub visibility: Option<u32>, pub notify_type: Option<u32>, pub offline_flag: Option<u32>, pub name_type: Option<u32>, pub member_name: Option<Vec<u8>>, pub timestamp: Option<u32>, pub event_version: Option<u64>, pub events: Vec<ChannelEvent>, pub from_role_info: Option<ChannelRole>, pub freq_limit_info: Option<ChannelFreqLimitInfo>, pub direct_message_member: Vec<DirectMessageMember>,
}

Fields

from_nick: Option<Vec<u8>>guild_name: Option<Vec<u8>>channel_name: Option<Vec<u8>>visibility: Option<u32>notify_type: Option<u32>offline_flag: Option<u32>name_type: Option<u32>member_name: Option<Vec<u8>>timestamp: Option<u32>event_version: Option<u64>events: Vec<ChannelEvent>from_role_info: Option<ChannelRole>freq_limit_info: Option<ChannelFreqLimitInfo>direct_message_member: Vec<DirectMessageMember>

Implementations

Returns the value of from_nick, or the default value if from_nick is unset.

Returns the value of guild_name, or the default value if guild_name is unset.

Returns the value of channel_name, or the default value if channel_name is unset.

Returns the value of visibility, or the default value if visibility is unset.

Returns the value of notify_type, or the default value if notify_type is unset.

Returns the value of offline_flag, or the default value if offline_flag is unset.

Returns the value of name_type, or the default value if name_type is unset.

Returns the value of member_name, or the default value if member_name is unset.

Returns the value of timestamp, or the default value if timestamp is unset.

Returns the value of event_version, or the default value if event_version is unset.