Struct ricq_guild::protocol::protobuf::ChannelMsgContent
source · [−]pub struct ChannelMsgContent {
pub head: Option<ChannelMsgHead>,
pub ctrl_head: Option<ChannelMsgCtrlHead>,
pub body: Option<MessageBody>,
pub ext_info: Option<ChannelExtInfo>,
}Fields
head: Option<ChannelMsgHead>ctrl_head: Option<ChannelMsgCtrlHead>body: Option<MessageBody>ext_info: Option<ChannelExtInfo>Trait Implementations
sourceimpl Clone for ChannelMsgContent
impl Clone for ChannelMsgContent
sourcefn clone(&self) -> ChannelMsgContent
fn clone(&self) -> ChannelMsgContent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ChannelMsgContent
impl Debug for ChannelMsgContent
sourceimpl Default for ChannelMsgContent
impl Default for ChannelMsgContent
sourceimpl Message for ChannelMsgContent
impl Message for ChannelMsgContent
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8, Global>
fn encode_to_vec(&self) -> Vec<u8, Global>
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>
fn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self. Read more
sourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
Decodes a length-delimited instance of the message from buffer, and
merges it into self. Read more
sourceimpl PartialEq<ChannelMsgContent> for ChannelMsgContent
impl PartialEq<ChannelMsgContent> for ChannelMsgContent
sourcefn eq(&self, other: &ChannelMsgContent) -> bool
fn eq(&self, other: &ChannelMsgContent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ChannelMsgContent) -> bool
fn ne(&self, other: &ChannelMsgContent) -> bool
This method tests for !=.
impl StructuralPartialEq for ChannelMsgContent