pub struct FirstViewRsp {
    pub result: Option<u32>,
    pub err_msg: Option<Vec<u8>>,
    pub seq: Option<u32>,
    pub udc_flag: Option<u32>,
    pub guild_count: Option<u32>,
    pub self_tinyid: Option<u64>,
    pub direct_message_switch: Option<u32>,
    pub direct_message_guild_count: Option<u32>,
}

Fields

result: Option<u32>err_msg: Option<Vec<u8>>seq: Option<u32>udc_flag: Option<u32>guild_count: Option<u32>self_tinyid: Option<u64>direct_message_switch: Option<u32>direct_message_guild_count: Option<u32>

Implementations

Returns the value of result, or the default value if result is unset.

Returns the value of err_msg, or the default value if err_msg is unset.

Returns the value of seq, or the default value if seq is unset.

Returns the value of udc_flag, or the default value if udc_flag is unset.

Returns the value of guild_count, or the default value if guild_count is unset.

Returns the value of self_tinyid, or the default value if self_tinyid is unset.

Returns the value of direct_message_switch, or the default value if direct_message_switch is unset.

Returns the value of direct_message_guild_count, or the default value if direct_message_guild_count is unset.