pub struct GuildMeta {
    pub guild_code: Option<u64>,
    pub create_time: Option<i64>,
    pub max_member_count: Option<i64>,
    pub member_count: Option<i64>,
    pub name: Option<String>,
    pub robot_max_num: Option<i32>,
    pub admin_max_num: Option<i32>,
    pub profile: Option<String>,
    pub avatar_seq: Option<i64>,
    pub owner_id: Option<u64>,
    pub cover_seq: Option<i64>,
    pub client_id: Option<i32>,
}

Fields

guild_code: Option<u64>create_time: Option<i64>max_member_count: Option<i64>member_count: Option<i64>name: Option<String>robot_max_num: Option<i32>admin_max_num: Option<i32>profile: Option<String>avatar_seq: Option<i64>owner_id: Option<u64>cover_seq: Option<i64>client_id: Option<i32>

Implementations

Returns the value of guild_code, or the default value if guild_code is unset.

Returns the value of create_time, or the default value if create_time is unset.

Returns the value of max_member_count, or the default value if max_member_count is unset.

Returns the value of member_count, or the default value if member_count is unset.

Returns the value of name, or the default value if name is unset.

Returns the value of robot_max_num, or the default value if robot_max_num is unset.

Returns the value of admin_max_num, or the default value if admin_max_num is unset.

Returns the value of profile, or the default value if profile is unset.

Returns the value of avatar_seq, or the default value if avatar_seq is unset.

Returns the value of owner_id, or the default value if owner_id is unset.

Returns the value of cover_seq, or the default value if cover_seq is unset.

Returns the value of client_id, or the default value if client_id is unset.