pub struct RichTextContentCount {
    pub text_word: Option<u64>,
    pub at: Option<u64>,
    pub url: Option<u64>,
    pub emoji: Option<u64>,
    pub image: Option<u64>,
    pub video: Option<u64>,
}

Fields

text_word: Option<u64>at: Option<u64>url: Option<u64>emoji: Option<u64>image: Option<u64>video: Option<u64>

Implementations

Returns the value of text_word, or the default value if text_word is unset.

Returns the value of at, or the default value if at is unset.

Returns the value of url, or the default value if url is unset.

Returns the value of emoji, or the default value if emoji is unset.

Returns the value of image, or the default value if image is unset.

Returns the value of video, or the default value if video is unset.