pub struct StComment {
Show 16 fields pub id: Option<String>, pub post_user: Option<StUser>, pub create_time: Option<u64>, pub content: Option<String>, pub reply_count: Option<u32>, pub vec_reply: Vec<StReply>, pub busi_data: Option<Vec<u8>>, pub like_info: Option<StLike>, pub type_flag: Option<u32>, pub at_uin_list: Vec<String>, pub type_flag2: Option<u32>, pub create_time_ns: Option<u64>, pub store_ext_info: Vec<CommonEntry>, pub third_id: Option<String>, pub source_type: Option<u32>, pub rich_contents: Option<StRichText>,
}

Fields

id: Option<String>post_user: Option<StUser>create_time: Option<u64>content: Option<String>reply_count: Option<u32>vec_reply: Vec<StReply>busi_data: Option<Vec<u8>>like_info: Option<StLike>type_flag: Option<u32>at_uin_list: Vec<String>type_flag2: Option<u32>create_time_ns: Option<u64>store_ext_info: Vec<CommonEntry>third_id: Option<String>source_type: Option<u32>rich_contents: Option<StRichText>

Implementations

Returns the value of id, or the default value if id is unset.

Returns the value of create_time, or the default value if create_time is unset.

Returns the value of content, or the default value if content is unset.

Returns the value of reply_count, or the default value if reply_count is unset.

Returns the value of busi_data, or the default value if busi_data is unset.

Returns the value of type_flag, or the default value if type_flag is unset.

Returns the value of type_flag2, or the default value if type_flag2 is unset.

Returns the value of create_time_ns, or the default value if create_time_ns is unset.

Returns the value of third_id, or the default value if third_id is unset.

Returns the value of source_type, or the default value if source_type is unset.